@@ -1,7 +1,7 @@
 package App::BashHistoryUtils;
 
-our $DATE = '2015-11-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-11-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,6 +48,14 @@ our %args_filtering = (
     },
 );
 
+our %args_formatting = (
+    strip_timestamp => {
+        summary => 'Strip timestamps',
+        schema => 'bool',
+        tags => ['category:formatting'],
+    },
+);
+
 sub _do {
     require Bash::History::Read;
     require Capture::Tiny;
@@ -62,6 +70,10 @@ sub _do {
     my $realhistfile = Cwd::realpath($args{histfile})
         or return [412, "Can't find realpath of '$histfile': $!"];
 
+    if ($which eq 'grep' && !defined($args{pattern})) {
+        return [400, "Missing required argument: pattern"];
+    }
+
     my $pat;
     if (defined $args{pattern}) {
         if ($args{ignore_case}) {
@@ -97,6 +109,10 @@ sub _do {
             if ($args{invert_match}) {
                 $main::PRINT = !$main::PRINT;
             }
+
+            if ($args{strip_timestamp}) {
+                undef $main::TS;
+            }
         };
     }
 
@@ -135,6 +151,7 @@ $SPEC{grep_bash_history_entries} = {
     args => {
         %arg_histfile,
         %args_filtering,
+        %args_formatting,
     },
 };
 sub grep_bash_history_entries {
@@ -147,6 +164,7 @@ $SPEC{delete_bash_history_entries} = {
     args => {
         %arg_histfile,
         %args_filtering,
+        %args_formatting,
     },
     features => {
         dry_run => 1,
@@ -163,6 +181,7 @@ sub delete_bash_history_entries {
         args => {
             %arg_histfile,
             %args_filtering,
+            %args_formatting,
             code => {
                 summary => 'Perl code to run for each entry',
                 description => <<'_',
@@ -199,7 +218,7 @@ App::BashHistoryUtils - CLI utilities related to bash history file
 
 =head1 VERSION
 
-This document describes version 0.02 of App::BashHistoryUtils (from Perl distribution App-BashHistoryUtils), released on 2015-11-05.
+This document describes version 0.03 of App::BashHistoryUtils (from Perl distribution App-BashHistoryUtils), released on 2015-11-07.
 
 =head1 DESCRIPTION
 
@@ -249,6 +268,10 @@ Match entries younger than a certain age.
 
 Match entries using a regex pattern.
 
+=item * B<strip_timestamp> => I<bool>
+
+Strip timestamps.
+
 =back
 
 Special arguments:
@@ -304,6 +327,10 @@ Match entries older than a certain age.
 
 Match entries younger than a certain age.
 
+=item * B<strip_timestamp> => I<bool>
+
+Strip timestamps.
+
 =back
 
 Returns an enveloped result (an array).
@@ -346,6 +373,10 @@ Match entries younger than a certain age.
 
 Match entries using a regex pattern.
 
+=item * B<strip_timestamp> => I<bool>
+
+Strip timestamps.
+
 =back
 
 Returns an enveloped result (an array).
